class CellTypes:
    ordinary: int
    pruned_branch: int
    library_ref: int
    merkle_proof: int
    merkle_update: int

class LevelMask:
    def __init__(self, m: int) -> None: ...
    @property
    def mask(self) -> int: ...
    @property
    def level(self) -> int: ...
    @property
    def hash_index(self) -> int: ...
    def get_level(self) -> int: ...
    def get_hash_index(self) -> int: ...
    def apply(self, level: int) -> LevelMask: ...
    def is_significant(self, level: int) -> bool: ...
