from typing import Any

class TlbError(Exception): ...

class TlbScheme:
    def serialize(self, *args: Any, **kwargs: Any) -> Any: ...
    @classmethod
    def deserialize(cls, *args: Any, **kwargs: Any) -> Any: ...
