PBKDF_ITERATIONS: int
words: list[str]

def get_secure_random_number(min_v: int, max_v: int) -> int: ...
def is_basic_seed(entropy: bytes) -> bool: ...
def mnemonic_is_valid(mnemo_words: list[str]) -> bool: ...
def mnemonic_new(words_count: int = ..., password: str | None = ...) -> list[str]: ...
def mnemonic_to_entropy(mnemo_words: list[str], password: str | None = ...) -> bytes: ...
def mnemonic_to_private_key(mnemo_words: list[str], password: str | None = ...) -> tuple[bytes, bytes]: ...
def mnemonic_to_seed(mnemo_words: list[str], seed: bytes, password: str | None = ...) -> bytes: ...
def mnemonic_to_wallet_key(mnemo_words: list[str], password: str | None = ...) -> tuple[bytes, bytes]: ...
def private_key_to_public_key(priv_k: bytes) -> bytes: ...
